@@ -13,13 +13,9 @@ HG38CYTOBAND_URL = (
 HG38GENES_FORMAT = "gtf"
 HG38GENES_URL = "https://s3.amazonaws.com/igv.broadinstitute.org/annotations/hg38/genes/Homo_sapiens.GRCh38.80.sorted.gtf.gz"
 HG38GENES_INDEX_URL = "https://s3.amazonaws.com/igv.broadinstitute.org/annotations/hg38/genes/Homo_sapiens.GRCh38.80.sorted.gtf.gz.tbi"
-HG19GENES_FORMAT = "bed"
-HG19GENES_URL = (
-    "https://s3.amazonaws.com/igv.broadinstitute.org/annotations/hg19/genes/refGene.hg19.bed.gz"
-)
-HG19GENES_INDEX_URL = (
-    "https://s3.amazonaws.com/igv.broadinstitute.org/annotations/hg19/genes/refGene.hg19.bed.gz.tbi"
-)
+HG19GENES_FORMAT = "refgene"
+HG19GENES_URL = "https://s3.amazonaws.com/igv.org.genomes/hg19/ncbiRefSeq.sorted.txt.gz"
+HG19GENES_INDEX_URL = "https://s3.amazonaws.com/igv.org.genomes/hg19/ncbiRefSeq.sorted.txt.gz.tbi"
 
 HG38CLINVAR_URL = "https://hgdownload.soe.ucsc.edu/gbdb/hg38/bbi/clinvar/clinvarMain.bb"
 HG19CLINVAR_URL = "https://hgdownload.soe.ucsc.edu/gbdb/hg19/bbi/clinvar/clinvarMain.bb"
@@ -49,6 +45,7 @@ CLINVAR_SNV_37 = {
     "type": "annotation",
     "sourceType": "file",
     "displayMode": "EXPANDED",
+    "visibilityWindow": 300000,
     "format": "bigBed",
     "maxRows": 30,
     "url": HG19CLINVAR_URL,
@@ -61,6 +58,7 @@ CLINVAR_SNV_38 = {
     "type": "annotation",
     "sourceType": "file",
     "displayMode": "EXPANDED",
+    "visibilityWindow": 300000,
     "format": "bigBed",
     "maxRows": 30,
     "url": HG38CLINVAR_URL,
@@ -73,6 +71,7 @@ CLINVAR_CNV_37 = {
     "type": "annotation",
     "sourceType": "file",
     "displayMode": "SQUISHED",
+    "visibilityWindow": 3000000000,
     "format": "bigBed",
     "height": 100,
     "url": HG19CLINVAR_CNVS_URL,
@@ -85,6 +84,7 @@ CLINVAR_CNV_38 = {
     "type": "annotation",
     "sourceType": "file",
     "displayMode": "SQUISHED",
+    "visibilityWindow": 3000000000,
     "format": "bigBed",
     "height": 100,
     "url": HG38CLINVAR_CNVS_URL,
@@ -97,6 +97,7 @@ HUMAN_GENES_37 = {
     "type": "annotation",
     "sourceType": "file",
     "displayMode": "EXPANDED",
+    "visibilityWindow": 300000000,
     "format": HG19GENES_FORMAT,
     "url": HG19GENES_URL,
     "indexURL": HG19GENES_INDEX_URL,
@@ -109,6 +110,7 @@ HUMAN_GENES_38 = {
     "type": "annotation",
     "sourceType": "file",
     "displayMode": "EXPANDED",
+    "visibilityWindow": 300000000,
     "format": HG38GENES_FORMAT,
     "url": HG38GENES_URL,
     "indexURL": HG38GENES_INDEX_URL,
