@@ -2,7 +2,6 @@ from flask import request, url_for
 from flask_login import current_user
 
 import scout.server.blueprints.cases.controllers as controllers
-from scout.server.blueprints.cases.controllers import redirect
 from scout.server.extensions import matchmaker, store
 
 
@@ -107,7 +106,7 @@ def test_matchmaker_add_snv(app, user_obj, case_obj, test_hpo_terms, mocker):
         )
         assert saved_results == 1
 
-        # THEN ine case should be uodated and a submission object correctly saved to database
+        # THEN one case should be uodated and a submission object correctly saved to database
         updated_case = store.case_collection.find_one()
         submission = updated_case["mme_submission"]
         assert (
@@ -115,6 +114,11 @@ def test_matchmaker_add_snv(app, user_obj, case_obj, test_hpo_terms, mocker):
             == test_variant["position"]
         )
 
+        # AND the corresponding event should be saved in the database:
+        mme_event = store.event_collection.find_one()
+        assert mme_event["verb"] == "mme_add"
+        assert mme_event["link"] == f"/{case_obj['owner']}/{case_obj['display_name']}"
+
 
 def test_matchmaker_add_sv(app, user_obj, case_obj, sv_variant_obj, mocker):
     """Test adding a patient with a SV to MatchMaker Exchange"""
@@ -197,6 +201,11 @@ def test_matchmaker_delete(app, mme_submission, user_obj, case_obj, mocker):
         updated_case = store.case_collection.find_one()
         assert updated_case.get("mme_submission") is None
 
+        # AND an event should have been added to the event collection:
+        mme_event = store.event_collection.find_one()
+        assert mme_event["verb"] == "mme_remove"
+        assert mme_event["link"] == f"/{case_obj['owner']}/{case_obj['display_name']}"
+
 
 def test_matchmaker_match(app, mme_submission, user_obj, case_obj, mocker):
     """testing controller function to match one patient against other patients from Scout"""
